// Implementation file for code version information
//
// Copyright (c) David Drysdale 2005-2006
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
// AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
// AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Except as contained in this notice, the name of the author shall not be
// used in advertising or otherwise to promote the sale, use or other dealings
// in this Software without prior written authorization from the author.

#include "version.h"

#include <cstring>
#include <cctype>
#include <cstdlib>

//! Global member variable that holds the Singleton for FileRegister
FileRegister* FileRegister::spInstance(0);

//! String conversion function
std::string FileRegister::to_str()
{
  std::stringstream ss;
  for (std::map<std::string, std::string>::const_iterator ii = version_.begin();
       ii != version_.end(); ++ii) {
    const std::string& name = ii->first;
    const std::string& ver = ii->second;
    ss << name << " => " << ver << " info " << info_[name] << " built " << date_[name] << " " << time_[name] << std::endl;
  }
  return ss.str();

}
int FileRegister::max_version()
{
  int max_version = 0;
  for (std::map<std::string, std::string>::const_iterator ii = version_.begin();
       ii != version_.end(); ++ii) {
    const std::string& ver = ii->second;
    const char *pc = ver.c_str();
    // Look for a colon
    pc = std::strchr(pc, ':');
    if (pc == 0) continue;
    pc++;

    // Skip whitespace
    while ((*pc != '\0') && std::isspace(*pc)) pc++;
    if (*pc == '\0') continue;

    // Look for a number at the current string position
    if (!std::isdigit(*pc)) continue;
    int version_number = std::atoi(pc);
    if (version_number > max_version) max_version = version_number;
  }
  return max_version;
}
